pycocoa.menus.ItemSeparator

Package pycocoa :: Module menus :: Class ItemSeparator |
[frames] | no frames]

# Class ItemSeparator

      object --+
               |
    bases._Type0 --+
                   |
        bases._Type1 --+
                       |
            bases._Type2 --+
                           |
                 _Item_Type2 --+
                               |
                              ItemSeparator

Python menu ItemSeparator Type, wrapping ObjC `NSMenuItem.separatorItem`.

Instance Methods
__init__(self) New ItemSeparator. |
Inherited from `bases._Type2`: `__str__` Inherited from `bases._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| action Get the separator's `action` (`None` always).
| tag Get the separator's `tag` (`0` always).
Inherited from `_Item_Type2`: `isSeparator`, `parent` Inherited from `bases._Type2`: `title` Inherited from `bases._Type1`: `NSdelegate`, `app` Inherited from `bases._Type0`: `NS`, `NSDelegate` Inherited from `object`: `__class__`

Method Details

### __init__(self) (Constructor) |
New ItemSeparator. Overrides: object.__init__

Property Details

### action Get the separator's `action` (`None` always). Get Method: action(self) - Get the separator's `action` (`None` always). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.

### tag Get the separator's `tag` (`0` always). Get Method: tag(self) - Get the separator's `tag` (`0` always). Set Method: Read_Only(self, ignored) - Throws an `AttributeError`, always.